@@ -9,7 +9,7 @@
 """
 import datetime
 import os
-import configparser  # 这个用于读取文件，写入文件会将中文注释删除
+from backports import configparser2 as configparser  # 这个用于读取文件，写入文件会将中文注释删除
 from XZGUtil.logger import conlog
 from XZGUtil.timeUtil import get_now_date, getdate
 
@@ -24,7 +24,9 @@ class upconfig(object):
         """
         self.updatePath = os.path.join(path if path else proDir, f"{file_name}.ini")
         self.config = configparser.RawConfigParser()
-        self.config.read(self.updatePath, encoding="utf-8-sig")
+        with open(self.updatePath, encoding="utf-8-sig") as f:
+            self.config.read_file(f)
+        # self.config.read(self.updatePath, encoding="utf-8-sig")
         self.update_tag = update_tag
 
     def get_information(self, name):
